package com.ruoyi.system.mapper.projectV2.common;

import com.ruoyi.system.domain.projectV2.common.SendSms;

import java.util.List;

/**
 * 短信日志Mapper接口
 * 
 * @author ruoyi
 * @date 2023-02-24
 */
public interface SendSmsMapper 
{
    /**
     * 查询短信日志
     * 
     * @param id 短信日志ID
     * @return 短信日志
     */
    public SendSms selectSendSmsById(Long id);

    /**
     * 查询短信日志列表
     * 
     * @param sendSms 短信日志
     * @return 短信日志集合
     */
    public List<SendSms> selectSendSmsList(SendSms sendSms);

    /**
     * 新增短信日志
     * 
     * @param sendSms 短信日志
     * @return 结果
     */
    public int insertSendSms(SendSms sendSms);

    /**
     * 修改短信日志
     * 
     * @param sendSms 短信日志
     * @return 结果
     */
    public int updateSendSms(SendSms sendSms);

    /**
     * 删除短信日志
     * 
     * @param id 短信日志ID
     * @return 结果
     */
    public int deleteSendSmsById(Long id);

    /**
     * 批量删除短信日志
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteSendSmsByIds(Long[] ids);
}
